@@ -412,13 +412,6 @@ void info_box()
 	return;
     }
   
-#ifdef DEBUG
-    fprintf(stderr,"%s\t%ld\t%ld\t%ld\t%u\n%s\t%s\n%s\n%s\n",archive->name,
-	    archive->tapeno,archive->size,archive->position,
-	    archive->add_info,archive->date,platform[pf],
-	    category[cat],archive->description);
-#endif
-
     infobox = newwin(22,60,(LINES - 21)/2,(COLS-60)/2);
     leaveok(infobox,TRUE);
     keypad(infobox,TRUE);
@@ -478,6 +471,10 @@ void info_box()
 	    else
 		mvwaddstr(infobox,20,2," Edit Info ");
 	}
+	else
+	    if (archive->add_info & CONTENTS_SAVED)
+		mvwaddstr(infobox,20,2," View Contents ");
+	
 	if (active == 6)
 	    set_color_pair(infobox,INV_INFOFRAME);
 	else
@@ -494,11 +491,10 @@ void info_box()
 	    set_color_pair(infobox,INV_INFOFRAME);
 	else
 	    set_color_pair(infobox,INFOFRAME);
-	if (tape->id)
+	if (tape->id || (archive->add_info & CONTENTS_SAVED))
 	    mvwaddstr(infobox,20,50," Cancel ");
 	else
 	    mvwaddstr(infobox,20,27," Cancel ");
-      
  	if (active == 4)
 	    set_color_pair(infobox,INV_INFOLABELS);
 	else
@@ -569,9 +565,13 @@ void info_box()
 		    else
 			active = 5;
 		}
+		else if (archive->add_info & CONTENTS_SAVED)
+		    active = 5;
 	    }
 	    else if (active == 7)
 		active = 0;
+	    else if (active == 5 && !tape->id)
+		active = 0;
 	    else
 		active++;
 	}
@@ -581,10 +581,15 @@ void info_box()
 	    {
 		if (tape->id)
 		    active = 7;
+		else if (archive->add_info & CONTENTS_SAVED)
+		    active = 5;
 	    }
 	    else if (active == 5)
-		if (edit)
-		    active = 4;
+		if (tape->id)
+		    if (edit)
+			active = 4;
+		    else
+			active = 0;
 		else
 		    active = 0;
 	    else
@@ -602,18 +607,25 @@ void info_box()
 	    }
 	    if (active == 5)
 	    {
-		if (edit)
-		{
-		    change_info(CHANGE_NAME_DESC_PF_CAT,archive_entry.name,
-				archive->tapeno,archive->position,platform[pf],
-				category[cat],archive_entry.description);
-		    changed = 1;
-		    edit = 0;
-		}
+		if (tape->id)
+		    if (edit)
+		    {
+			change_info(CHANGE_NAME_DESC_PF_CAT,archive_entry.name,
+				    archive->tapeno,archive->position,platform[pf],
+				    category[cat],archive_entry.description);
+			changed = 1;
+			edit = 0;
+		    }
+		    else
+		    {
+			edit = 1;
+			active = 1;
+		    }
 		else
 		{
-		    edit = 1;
-		    active = 1;
+		    extract_selected_archive(JUST_VIEW);
+		    touchwin(listbox);
+		    wrefresh(listbox);
 		}
 	    }
 	    if (active == 6)
@@ -720,7 +732,8 @@ void search_list(char *substring,int pos)
     print_footer("");
     if (!strlen(substring))
 	return;
-    
+
+    print_footer("Searching...");
     for (i = 0; substring[i] != '\0'; i++)
 	substring[i] = toupper(substring[i]);
     
@@ -730,25 +743,18 @@ void search_list(char *substring,int pos)
     for (i = 0; i <= focus_item; i++)
 	p = p->next;
 
-    while (p != NULL)
-    {
+    for (; p != NULL; i++, p = p->next)
 	if ((strmatch(p->name,substring)) && ((pos < 0) || (pos == p->position))) 
 	    break;
-	i++;
-	p = p->next;
-    }
     
     if (p != NULL)
 	goto found;
     
     print_footer("Wrapped...");
     p = archive_head;
-    for (i = 0; i <= focus_item; i++)
-    {
+    for (i = 0; i <= focus_item; i++, p = p->next)
 	if ((strmatch(p->name,substring)) && ((pos < 0) || (pos == p-> position)))
 	    break;
-	p = p->next;
-    }
     
     if (i <= focus_item)
 	goto found;
@@ -779,7 +785,8 @@ found:
 
 /*************************************************************************/
 /* Name:     comment_focussed_archive                                    */
-/* Purpose:  Searches a list entry that matches the substring            */
+/* Purpose:  Give the archive a certain flag so it doesn't appear in the */
+/*           archive list.                                               */
 /*************************************************************************/
 void comment_focussed_archive()
 {
@@ -787,6 +794,12 @@ void comment_focussed_archive()
     int i = 0;
     char msg[80];
     
+    if (no_listitems == 0)
+    {
+	print_footer("No archive has the focus.");
+	return;
+    }
+    
     le = archive_head;
     while (i < focus_item)
     {
