@@ -82,6 +82,8 @@ void utils_chosen_cell()
     case 2:
 	EntryField("Enter search substring:",ARCHIVENAMELENGTH,
 		   searchstring,0,searchstring,WITH_SPECIAL_CHARS);
+	touchwin(listbox);
+	wrefresh(listbox);
 	search_list(searchstring,-1);
 	destroy_utils_popup();
 	break;
@@ -183,7 +185,7 @@ void destroy_utils_popup()
 /* Name:     add_archive_to_tape                                         */
 /* Purpose:  Appends a new archive at the end of the tape                */
 /*************************************************************************/
-void add_archive_to_tape(char *filename,long size)
+void add_archive_to_tape(char *filename,long size,int count)
 {
     FILE *fp1,*fp2 = NULL;
     char name[MAXLEN],tarpath[MAXLEN],dummy[MAXLEN];
@@ -193,7 +195,8 @@ void add_archive_to_tape(char *filename,long size)
     int len, c, i, fertig = 0, x = 0, y = 0, active = 0, pf = 0, cat = 0;
     long filesize;
   
-    /* Get first entry of the file list for the default archive name */
+    /* Get first entry of the file list for the default archive name, but only if 
+       only one element was marked */
     if ((fp1 = fopen(filename,"r")) == NULL)
     {
 	fprintf(stderr,"Sorry! Internal error 101! Look in the fucking manual!\n");
@@ -207,6 +210,9 @@ void add_archive_to_tape(char *filename,long size)
     }
     name[strlen(name)-1] = '\0';
     fclose(fp1);
+    
+    if (count > 1)
+	strcpy(name,"");
 
     strncpy(archive->name,name,ARCHIVENAMELENGTH);
 #ifdef DEBUG
@@ -675,7 +681,7 @@ void extract_archive()
 /* Name:     extract_selected_archive                                    */
 /* Purpose:  Extracts a selected part of archive                         */
 /*************************************************************************/
-void extract_selected_archive()
+void extract_selected_archive(int mode)
 {
     FILE *fp,*fp2 = NULL;
     char cmd[MAXLEN],name[MAXLEN],dummy[MAXLEN];
@@ -751,6 +757,9 @@ void extract_selected_archive()
     else
     {
 tape_n_save:
+	if (mode == JUST_VIEW)
+	    goto tarlistbox_end;
+	
 	if (MessageBox("Save the contents of archive ?",2,YESNO,1))
 	    save_contents_now = 1;
 	touchwin(listbox);
@@ -758,6 +767,9 @@ tape_n_save:
 	touchwin(infobox);
 	wrefresh(infobox);
 tape:
+	if (mode == JUST_VIEW)
+	    goto tarlistbox_end;
+	
 	if (watch_tape)
 	{
 	    create_watch_win(" Archive Contents Log ");
@@ -829,7 +841,9 @@ tape:
 	}
     }
     destroy_watch_win();
-    handle_tar_listbox();
+    handle_tar_listbox(mode);
+tarlistbox_end:
+    return;
 }
 
 
